.cke_button__about_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -0px !important;
}

.cke_button__bold_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -24px !important;
}

.cke_button__italic_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -48px !important;
}

.cke_button__strike_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -72px !important;
}

.cke_button__subscript_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -96px !important;
}

.cke_button__superscript_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -120px !important;
}

.cke_button__underline_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -144px !important;
}

.cke_button__bidiltr_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -168px !important;
}

.cke_button__bidirtl_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -192px !important;
}

.cke_button__blockquote_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -216px !important;
}

.cke_rtl .cke_button__copy_icon,
.cke_mixed_dir_content .cke_rtl .cke_button__copy_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -240px !important;
}

.cke_ltr .cke_button__copy_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -264px !important;
}

.cke_rtl .cke_button__cut_icon,
.cke_mixed_dir_content .cke_rtl .cke_button__cut_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -288px !important;
}

.cke_ltr .cke_button__cut_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -312px !important;
}

.cke_rtl .cke_button__paste_icon,
.cke_mixed_dir_content .cke_rtl .cke_button__paste_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -336px !important;
}

.cke_ltr .cke_button__paste_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -360px !important;
}

.cke_button__bgcolor_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -384px !important;
}

.cke_button__textcolor_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -408px !important;
}

.cke_rtl .cke_button__templates_icon,
.cke_mixed_dir_content .cke_rtl .cke_button__templates_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -432px !important;
}

.cke_ltr .cke_button__templates_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -456px !important;
}

.cke_button__copyformatting_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -480px !important;
}

.cke_button__creatediv_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -504px !important;
}

.cke_rtl .cke_button__find_icon,
.cke_mixed_dir_content .cke_rtl .cke_button__find_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -528px !important;
}

.cke_ltr .cke_button__find_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -552px !important;
}

.cke_button__replace_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -576px !important;
}

.cke_button__flash_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -600px !important;
}

.cke_button__button_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -624px !important;
}

.cke_button__checkbox_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -648px !important;
}

.cke_button__form_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -672px !important;
}

.cke_button__hiddenfield_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -696px !important;
}

.cke_button__imagebutton_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -720px !important;
}

.cke_button__radio_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -744px !important;
}

.cke_rtl .cke_button__select_icon,
.cke_mixed_dir_content .cke_rtl .cke_button__select_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -768px !important;
}

.cke_ltr .cke_button__select_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -792px !important;
}

.cke_rtl .cke_button__textarea_icon,
.cke_mixed_dir_content .cke_rtl .cke_button__textarea_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -816px !important;
}

.cke_ltr .cke_button__textarea_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -840px !important;
}

.cke_rtl .cke_button__textfield_icon,
.cke_mixed_dir_content .cke_rtl .cke_button__textfield_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -864px !important;
}

.cke_ltr .cke_button__textfield_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -888px !important;
}

.cke_button__horizontalrule_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -912px !important;
}

.cke_button__iframe_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -936px !important;
}

.cke_button__image_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -960px !important;
}

.cke_rtl .cke_button__indent_icon,
.cke_mixed_dir_content .cke_rtl .cke_button__indent_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -984px !important;
}

.cke_ltr .cke_button__indent_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1008px !important;
}

.cke_rtl .cke_button__outdent_icon,
.cke_mixed_dir_content .cke_rtl .cke_button__outdent_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1032px !important;
}

.cke_ltr .cke_button__outdent_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1056px !important;
}

.cke_button__smiley_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1080px !important;
}

.cke_button__justifyblock_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1104px !important;
}

.cke_button__justifycenter_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1128px !important;
}

.cke_button__justifyleft_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1152px !important;
}

.cke_button__justifyright_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1176px !important;
}

.cke_button__language_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1200px !important;
}

.cke_rtl .cke_button__anchor_icon,
.cke_mixed_dir_content .cke_rtl .cke_button__anchor_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1224px !important;
}

.cke_ltr .cke_button__anchor_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1248px !important;
}

.cke_button__link_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1272px !important;
}

.cke_button__unlink_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1296px !important;
}

.cke_rtl .cke_button__bulletedlist_icon,
.cke_mixed_dir_content .cke_rtl .cke_button__bulletedlist_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1320px !important;
}

.cke_ltr .cke_button__bulletedlist_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1344px !important;
}

.cke_rtl .cke_button__numberedlist_icon,
.cke_mixed_dir_content .cke_rtl .cke_button__numberedlist_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1368px !important;
}

.cke_ltr .cke_button__numberedlist_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1392px !important;
}

.cke_button__maximize_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1416px !important;
}

.cke_rtl .cke_button__newpage_icon,
.cke_mixed_dir_content .cke_rtl .cke_button__newpage_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1440px !important;
}

.cke_ltr .cke_button__newpage_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1464px !important;
}

.cke_rtl .cke_button__pagebreak_icon,
.cke_mixed_dir_content .cke_rtl .cke_button__pagebreak_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1488px !important;
}

.cke_ltr .cke_button__pagebreak_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1512px !important;
}

.cke_rtl .cke_button__pastetext_icon,
.cke_mixed_dir_content .cke_rtl .cke_button__pastetext_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1536px !important;
}

.cke_ltr .cke_button__pastetext_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1560px !important;
}

.cke_rtl .cke_button__pastefromword_icon,
.cke_mixed_dir_content .cke_rtl .cke_button__pastefromword_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1584px !important;
}

.cke_ltr .cke_button__pastefromword_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1608px !important;
}

.cke_rtl .cke_button__preview_icon,
.cke_mixed_dir_content .cke_rtl .cke_button__preview_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1632px !important;
}

.cke_ltr .cke_button__preview_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1656px !important;
}

.cke_button__print_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1680px !important;
}

.cke_button__removeformat_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1704px !important;
}

.cke_button__save_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1728px !important;
}

.cke_button__selectall_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1752px !important;
}

.cke_rtl .cke_button__showblocks_icon,
.cke_mixed_dir_content .cke_rtl .cke_button__showblocks_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1776px !important;
}

.cke_ltr .cke_button__showblocks_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1800px !important;
}

.cke_rtl .cke_button__source_icon,
.cke_mixed_dir_content .cke_rtl .cke_button__source_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1824px !important;
}

.cke_ltr .cke_button__source_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1848px !important;
}

.cke_button__specialchar_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1872px !important;
}

.cke_button__scayt_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1896px !important;
}

.cke_button__table_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1920px !important;
}

.cke_rtl .cke_button__redo_icon,
.cke_mixed_dir_content .cke_rtl .cke_button__redo_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1944px !important;
}

.cke_ltr .cke_button__redo_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1968px !important;
}

.cke_rtl .cke_button__undo_icon,
.cke_mixed_dir_content .cke_rtl .cke_button__undo_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -1992px !important;
}

.cke_ltr .cke_button__undo_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -2016px !important;
}

.cke_button__spellchecker_icon {
    background: url(#{$path-icon}?t=dee99e2) no-repeat 0 -2040px !important;
}

.cke_hidpi .cke_button__about_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -0px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__bold_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -24px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__italic_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -48px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__strike_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -72px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__subscript_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -96px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__superscript_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -120px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__underline_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -144px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__bidiltr_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -168px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__bidirtl_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -192px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__blockquote_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -216px !important;
    background-size: 16px !important;
}

.cke_rtl.cke_hidpi .cke_button__copy_icon,
.cke_hidpi .cke_mixed_dir_content .cke_rtl .cke_button__copy_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -240px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_ltr .cke_button__copy_icon,
.cke_ltr.cke_hidpi .cke_button__copy_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -264px !important;
    background-size: 16px !important;
}

.cke_rtl.cke_hidpi .cke_button__cut_icon,
.cke_hidpi .cke_mixed_dir_content .cke_rtl .cke_button__cut_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -288px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_ltr .cke_button__cut_icon,
.cke_ltr.cke_hidpi .cke_button__cut_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -312px !important;
    background-size: 16px !important;
}

.cke_rtl.cke_hidpi .cke_button__paste_icon,
.cke_hidpi .cke_mixed_dir_content .cke_rtl .cke_button__paste_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -336px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_ltr .cke_button__paste_icon,
.cke_ltr.cke_hidpi .cke_button__paste_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -360px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__bgcolor_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -384px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__textcolor_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -408px !important;
    background-size: 16px !important;
}

.cke_rtl.cke_hidpi .cke_button__templates_icon,
.cke_hidpi .cke_mixed_dir_content .cke_rtl .cke_button__templates_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -432px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_ltr .cke_button__templates_icon,
.cke_ltr.cke_hidpi .cke_button__templates_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -456px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__copyformatting_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -480px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__creatediv_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -504px !important;
    background-size: 16px !important;
}

.cke_rtl.cke_hidpi .cke_button__find_icon,
.cke_hidpi .cke_mixed_dir_content .cke_rtl .cke_button__find_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -528px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_ltr .cke_button__find_icon,
.cke_ltr.cke_hidpi .cke_button__find_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -552px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__replace_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -576px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__flash_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -600px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__button_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -624px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__checkbox_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -648px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__form_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -672px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__hiddenfield_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -696px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__imagebutton_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -720px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__radio_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -744px !important;
    background-size: 16px !important;
}

.cke_rtl.cke_hidpi .cke_button__select_icon,
.cke_hidpi .cke_mixed_dir_content .cke_rtl .cke_button__select_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -768px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_ltr .cke_button__select_icon,
.cke_ltr.cke_hidpi .cke_button__select_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -792px !important;
    background-size: 16px !important;
}

.cke_rtl.cke_hidpi .cke_button__textarea_icon,
.cke_hidpi .cke_mixed_dir_content .cke_rtl .cke_button__textarea_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -816px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_ltr .cke_button__textarea_icon,
.cke_ltr.cke_hidpi .cke_button__textarea_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -840px !important;
    background-size: 16px !important;
}

.cke_rtl.cke_hidpi .cke_button__textfield_icon,
.cke_hidpi .cke_mixed_dir_content .cke_rtl .cke_button__textfield_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -864px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_ltr .cke_button__textfield_icon,
.cke_ltr.cke_hidpi .cke_button__textfield_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -888px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__horizontalrule_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -912px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__iframe_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -936px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__image_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -960px !important;
    background-size: 16px !important;
}

.cke_rtl.cke_hidpi .cke_button__indent_icon,
.cke_hidpi .cke_mixed_dir_content .cke_rtl .cke_button__indent_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -984px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_ltr .cke_button__indent_icon,
.cke_ltr.cke_hidpi .cke_button__indent_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1008px !important;
    background-size: 16px !important;
}

.cke_rtl.cke_hidpi .cke_button__outdent_icon,
.cke_hidpi .cke_mixed_dir_content .cke_rtl .cke_button__outdent_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1032px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_ltr .cke_button__outdent_icon,
.cke_ltr.cke_hidpi .cke_button__outdent_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1056px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__smiley_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1080px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__justifyblock_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1104px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__justifycenter_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1128px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__justifyleft_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1152px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__justifyright_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1176px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__language_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1200px !important;
    background-size: 16px !important;
}

.cke_rtl.cke_hidpi .cke_button__anchor_icon,
.cke_hidpi .cke_mixed_dir_content .cke_rtl .cke_button__anchor_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1224px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_ltr .cke_button__anchor_icon,
.cke_ltr.cke_hidpi .cke_button__anchor_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1248px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__link_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1272px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__unlink_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1296px !important;
    background-size: 16px !important;
}

.cke_rtl.cke_hidpi .cke_button__bulletedlist_icon,
.cke_hidpi .cke_mixed_dir_content .cke_rtl .cke_button__bulletedlist_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1320px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_ltr .cke_button__bulletedlist_icon,
.cke_ltr.cke_hidpi .cke_button__bulletedlist_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1344px !important;
    background-size: 16px !important;
}

.cke_rtl.cke_hidpi .cke_button__numberedlist_icon,
.cke_hidpi .cke_mixed_dir_content .cke_rtl .cke_button__numberedlist_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1368px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_ltr .cke_button__numberedlist_icon,
.cke_ltr.cke_hidpi .cke_button__numberedlist_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1392px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__maximize_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1416px !important;
    background-size: 16px !important;
}

.cke_rtl.cke_hidpi .cke_button__newpage_icon,
.cke_hidpi .cke_mixed_dir_content .cke_rtl .cke_button__newpage_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1440px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_ltr .cke_button__newpage_icon,
.cke_ltr.cke_hidpi .cke_button__newpage_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1464px !important;
    background-size: 16px !important;
}

.cke_rtl.cke_hidpi .cke_button__pagebreak_icon,
.cke_hidpi .cke_mixed_dir_content .cke_rtl .cke_button__pagebreak_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1488px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_ltr .cke_button__pagebreak_icon,
.cke_ltr.cke_hidpi .cke_button__pagebreak_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1512px !important;
    background-size: 16px !important;
}

.cke_rtl.cke_hidpi .cke_button__pastetext_icon,
.cke_hidpi .cke_mixed_dir_content .cke_rtl .cke_button__pastetext_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1536px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_ltr .cke_button__pastetext_icon,
.cke_ltr.cke_hidpi .cke_button__pastetext_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1560px !important;
    background-size: 16px !important;
}

.cke_rtl.cke_hidpi .cke_button__pastefromword_icon,
.cke_hidpi .cke_mixed_dir_content .cke_rtl .cke_button__pastefromword_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1584px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_ltr .cke_button__pastefromword_icon,
.cke_ltr.cke_hidpi .cke_button__pastefromword_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1608px !important;
    background-size: 16px !important;
}

.cke_rtl.cke_hidpi .cke_button__preview_icon,
.cke_hidpi .cke_mixed_dir_content .cke_rtl .cke_button__preview_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1632px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_ltr .cke_button__preview_icon,
.cke_ltr.cke_hidpi .cke_button__preview_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1656px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__print_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1680px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__removeformat_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1704px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__save_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1728px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__selectall_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1752px !important;
    background-size: 16px !important;
}

.cke_rtl.cke_hidpi .cke_button__showblocks_icon,
.cke_hidpi .cke_mixed_dir_content .cke_rtl .cke_button__showblocks_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1776px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_ltr .cke_button__showblocks_icon,
.cke_ltr.cke_hidpi .cke_button__showblocks_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1800px !important;
    background-size: 16px !important;
}

.cke_rtl.cke_hidpi .cke_button__source_icon,
.cke_hidpi .cke_mixed_dir_content .cke_rtl .cke_button__source_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1824px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_ltr .cke_button__source_icon,
.cke_ltr.cke_hidpi .cke_button__source_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1848px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__specialchar_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1872px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__scayt_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1896px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__table_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1920px !important;
    background-size: 16px !important;
}

.cke_rtl.cke_hidpi .cke_button__redo_icon,
.cke_hidpi .cke_mixed_dir_content .cke_rtl .cke_button__redo_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1944px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_ltr .cke_button__redo_icon,
.cke_ltr.cke_hidpi .cke_button__redo_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1968px !important;
    background-size: 16px !important;
}

.cke_rtl.cke_hidpi .cke_button__undo_icon,
.cke_hidpi .cke_mixed_dir_content .cke_rtl .cke_button__undo_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -1992px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_ltr .cke_button__undo_icon,
.cke_ltr.cke_hidpi .cke_button__undo_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -2016px !important;
    background-size: 16px !important;
}

.cke_hidpi .cke_button__spellchecker_icon {
    background: url(icons_hidpi.png?t=dee99e2) no-repeat 0 -2040px !important;
    background-size: 16px !important;
}
